<?php

/**
 * Admin Notice.
 *
 * @package MagazineCraft
 */

// Exit if accessed directly.
defined('ABSPATH') || exit;

/**
 * Magazinecraft Admin Notice
 */
class Magazinecraft_Admin_Welcome_Notice
{

    /**
     * __construct
     */
    public function __construct()
    {
        $this->setup_hooks();
        add_action('wp_loaded', array($this, 'welcome_notice'), 20);
        add_action('wp_loaded', array($this, 'hide_notices'), 15);
    }

    /**
     * Setup hooks.
     *
     * @return void
     */
    private function setup_hooks()
    {
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));
    }

    /**
     * Enqueue scripts.
     *
     * @return void
     */
    public function enqueue_scripts()
    {
        wp_enqueue_style('magazinecraft-admin-dashboard', get_template_directory_uri() . '/css/admin/dashboard.css', array(), MAGAZINECRAFT_VERSION);
    }

    /**
     * Welcome notice.
     *
     * @return void
     */
    public function welcome_notice()
    {
        if (!get_option('magazinecraft_admin_notice_welcome')) {
            add_action('admin_notices', array($this, 'welcome_notice_markup'));
        }
    }

    /**
     * Welcome notice markup.
     */
    public function welcome_notice_markup()
    {
        $mb_dismiss_url = wp_nonce_url(
            remove_query_arg(array('activated'), add_query_arg('magazinecraft-hide-notice', 'welcome')),
            'magazinecraft_hide_notices_nonce',
            '_magazinecraft_notice_nonce'
        );
?>
        <div id="message" class="notice notice-success magazinecraft-notice">
            <a class="magazinecraft-message-close notice-dismiss" href="<?php echo esc_url($mb_dismiss_url); ?>"><?php esc_html_e('Don\'t display this again.', 'magazinecraft'); ?></a>

            <div class="magazinecraft-notice-header">
                <h3><?php esc_html_e('Congratulations!', 'magazinecraft'); ?></h3>
                <p class="notice-desc"><?php esc_html_e('MagazineCraft is now installed and ready to use.', 'magazinecraft'); ?></p>
                <hr>
            </div>

            <div class="magazinecraft-notice-content-wrap">
                <div class="magazinecraft-notice-image">
                    <img class="magazinecraft-screenshot" src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png" alt="<?php echo esc_attr('MagazineCraft', 'magazinecraft'); ?>" />
                </div>

                <div class="magazinecraft-notice-content">
                    <div class="mb-notice-content-col">
                        <h3>
                            <span class="dashicons dashicons-format-aside"></span>
                            <?php esc_html_e('Documentation', 'magazinecraft'); ?>
                        </h3>
                        <p><?php esc_html_e('Need more details? Please check our full documentation for detailed information on how to use MagazineCraft.', 'magazinecraft'); ?></p>
                        <a href="<?php echo esc_url('https://odiethemes.com/docs/magazinecraft/installation/'); ?>" class="button" target="_blank"><?php esc_html_e('Read Documentation', 'magazinecraft'); ?></a>
                    </div>
                    <div class="mb-notice-content-col">
                    </div>
                </div>
            </div>
        </div>
<?php
    }

    /**
     * Hide a notice if the GET variable is set.
     */
    public function hide_notices()
    {
        if (isset($_GET['magazinecraft-hide-notice']) && isset($_GET['_magazinecraft_notice_nonce'])) { // WPCS: input var ok.
            if (!wp_verify_nonce(sanitize_key($_GET['_magazinecraft_notice_nonce']), 'magazinecraft_hide_notices_nonce')) {
                wp_die(esc_html__('Action failed. Please refresh the page and retry.', 'magazinecraft'));
            }

            if (!current_user_can('manage_options')) {
                wp_die(esc_html__('Cheating is not allowed.', 'magazinecraft'));
            }

            $hide_notice = sanitize_text_field(wp_unslash($_GET['magazinecraft-hide-notice']));

            // Hide.
            if ('welcome' === $_GET['magazinecraft-hide-notice']) {
                update_option('magazinecraft_admin_notice_' . $hide_notice, 1);
            } else { // Show.
                delete_option('magazinecraft_admin_notice_' . $hide_notice);
            }
        }
    }
}

new Magazinecraft_Admin_Welcome_Notice();
