<?php

/**
 * MagazineCraft Theme Customizer
 *
 * @package MagazineCraft
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function magazinecraft_customize_register($wp_customize)
{
	$wp_customize->get_setting('blogname')->transport         = 'postMessage';
	$wp_customize->get_setting('blogdescription')->transport  = 'postMessage';
	$wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

	if (isset($wp_customize->selective_refresh)) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'magazinecraft_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'magazinecraft_customize_partial_blogdescription',
			)
		);
	}

	include get_template_directory() . '/inc/customizer/other-functions.php';
	include get_template_directory() . '/inc/customizer/class-magazinecraft-dropdown-category-control.php';
	include get_template_directory() . '/inc/customizer/header-options.php';
	include get_template_directory() . '/inc/customizer/footer-options.php';
	include get_template_directory() . '/inc/customizer/frontpage-options.php';
	include get_template_directory() . '/inc/customizer/design-options.php';

	$wp_customize->get_section('header_image')->panel    = 'magazinecraft_header_options';
	$wp_customize->get_section('header_image')->priority = 999;

	// Logo hight setting.
	$wp_customize->add_setting(
		'magazinecraft_custom_logo_height',
		array(
			'default'           => false,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'magazinecraft_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'magazinecraft_custom_logo_height',
		array(
			'type'     => 'checkbox',
			'label'    => __('Set custom height for Logo', 'magazinecraft'),
			'section'  => 'title_tagline',
			'settings' => 'magazinecraft_custom_logo_height',
			'priority' => 8,
		)
	);
	$wp_customize->add_setting(
		'magazinecraft_logo_height',
		array(
			'default'           => 60,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'magazinecraft_logo_height',
		array(
			'label'           => __('Enter logo height (in px)', 'magazinecraft'),
			'type'            => 'number',
			'section'         => 'title_tagline',
			'setting'         => 'magazinecraft_logo_height',
			'priority'        => '9',
			'active_callback' => function () {
				if (get_theme_mod('magazinecraft_custom_logo_height', false)) {
					return true;
				}
				return false;
			},
		)
	);

	$wp_customize->add_setting(
		'magazinecraft_primary_color',
		array(
			'default'              => '#2563eb',
			'capability'           => 'edit_theme_options',
			'sanitize_callback'    => 'sanitize_hex_color',
			'sanitize_js_callback' => 'magazinecraft_color_escaping_option_sanitize',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'magazinecraft_primary_color',
			array(
				'label'       => esc_html__('Select Primary Color:', 'magazinecraft'),
				'description' => esc_html__('This will reflect in links, buttons and many other places. Choose a color to match your site.', 'magazinecraft'),
				'section'     => 'colors',
				'settings'    => 'magazinecraft_primary_color',
				'priority'    => 1,
			)
		)
	);
}
add_action('customize_register', 'magazinecraft_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function magazinecraft_customize_partial_blogname()
{
	bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function magazinecraft_customize_partial_blogdescription()
{
	bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function magazinecraft_customize_preview_js()
{
	wp_enqueue_script('magazinecraft-customizer', get_template_directory_uri() . '/js/customizer.js', array('customize-preview'), MAGAZINECRAFT_VERSION, true);
}
add_action('customize_preview_init', 'magazinecraft_customize_preview_js');


/**
 * Magazinecraft Custom css for customizer.
 *
 * @return void
 */
function magazinecraft_styles_method()
{
	$magazinecraft_primary_color = get_theme_mod('magazinecraft_primary_color', '#2563eb');
	$magazinecraft_internal_css  = '';

	if ('#2563eb' !== $magazinecraft_primary_color) {
		$magazinecraft_internal_css = "
		a,
		h2.entry-title a:hover,
		.entry-meta .cat-links a,
		.entry-footer .cat-links a,
		.wp-block-latest-posts li a:hover,
		.widget a:hover,
		.text-blue-600 {
			color: {$magazinecraft_primary_color};
		}
		.wp-block-button:not(.is-style-outline) .wp-block-button__link,
		.cover-button,
		.bg-blue-600 {
			background-color: {$magazinecraft_primary_color};
		}
		.search-submit, 
		.wp-block-search__button {
			border-color: {$magazinecraft_primary_color};
			background-color: {$magazinecraft_primary_color};
		}
		.border-blue-600 {
			border-color: {$magazinecraft_primary_color};
		}
		";
	}

	wp_add_inline_style('magazinecraft-theme-style', $magazinecraft_internal_css);

	if ('option1' === get_theme_mod('magazinecraft_font_combo', 'default')) {
		wp_dequeue_style('magazinecraft-fonts');
		wp_enqueue_style(
			'magazinecraft-fonts-option1',
			wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Lora:wght@400;500;600;700&display=swap' ),
			array(),
			MAGAZINECRAFT_VERSION
		);

		$magazinecraft_internal_font_css = "
		html, body, .font-sans {
			font-family: 'Lora', serif;
		}
		";

		wp_add_inline_style('magazinecraft-fonts-option1', $magazinecraft_internal_font_css);
	}

	if ('option2' === get_theme_mod('magazinecraft_font_combo', 'default')) {
		wp_dequeue_style('magazinecraft-fonts');
		wp_enqueue_style(
			'magazinecraft-fonts-option2',
			wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Barlow+Semi+Condensed:wght@400;500;600;700&display=swap' ),
			array(),
			MAGAZINECRAFT_VERSION
		);

		$magazinecraft_internal_font_css = "
		html, body, .font-sans {
			font-family: 'Barlow Semi Condensed', sans-serif;
		}
		";

		wp_add_inline_style('magazinecraft-fonts-option2', $magazinecraft_internal_font_css);
	}

	if ('option3' === get_theme_mod('magazinecraft_font_combo', 'default')) {
		wp_dequeue_style('magazinecraft-fonts');
		wp_enqueue_style(
			'magazinecraft-fonts-option3',
			wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Playfair+Display:wght@400;500;600;700&display=swap' ),
			array(),
			MAGAZINECRAFT_VERSION
		);

		$magazinecraft_internal_font_css = "
		html, body, .font-sans {
			font-family: 'Playfair Display', serif;
		}
		";

		wp_add_inline_style('magazinecraft-fonts-option3', $magazinecraft_internal_font_css);
	}
}
add_action('wp_enqueue_scripts', 'magazinecraft_styles_method');


/**
 * magazinecraft_custom_logo_css
 *
 * @return void
 */
function magazinecraft_custom_logo_css()
{
	if (get_theme_mod('magazinecraft_custom_logo_height', false)) {
?>
		<style type="text/css" id="custom-theme-css">
			.custom-logo {
				height: <?php echo esc_attr(get_theme_mod('magazinecraft_logo_height', '60')); ?>px;
				width: auto;
			}
		</style>
<?php
	}
}
add_action('wp_head', 'magazinecraft_custom_logo_css', 100);
