<?php

/**
 * MagazineCraft Theme Customizer - Frontpage options
 *
 * @package MagazineCraft
 */

// Add Design Options panel.
$wp_customize->add_panel(
    'magazinecraft_frontpage_options',
    array(
        'capability'  => 'edit_theme_options',
        'description' => __('Change the Frontpage Settings', 'magazinecraft'),
        'priority'    => 503,
        'title'       => __('Frontpage Options', 'magazinecraft'),
    )
);

// Add frontpage banner settings section.
$wp_customize->add_section(
    'magazinecraft_banner_section',
    array(
        'title' => __('Banner Options', 'magazinecraft'),
        'panel' => 'magazinecraft_frontpage_options',
    )
);

$wp_customize->add_setting(
    'magazinecraft_show_banner_section',
    array(
        'priority'          => 1,
        'default'           => true,
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'magazinecraft_show_banner_section',
    array(
        'type'     => 'checkbox',
        'label'    => __('Check to show the banner section on frontpage', 'magazinecraft'),
        'section'  => 'magazinecraft_banner_section',
        'settings' => 'magazinecraft_show_banner_section',
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner_design',
    array(
        'default'           => 'design2',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_radio',
    )
);
$wp_customize->add_control(
    'magazinecraft_banner_design',
    array(
        'type'            => 'radio',
        'label'           => esc_html__('Banner Design:', 'magazinecraft'),
        'section'         => 'magazinecraft_banner_section',
        'settings'        => 'magazinecraft_banner_design',
        'choices'         => array(
            'design1'  => esc_html__('Type 1', 'magazinecraft'),
            'design2' => esc_html__('Type 2', 'magazinecraft'),
        ),
        'active_callback' => function () {
            if (get_theme_mod('magazinecraft_show_banner_section', true)) {
                return true;
            }
            return false;
        },
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner1_title',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'magazinecraft_banner1_title',
    array(
        'type'            => 'text',
        'label'           => esc_html__('Banner Title Text:', 'magazinecraft'),
        'section'         => 'magazinecraft_banner_section',
        'settings'        => 'magazinecraft_banner1_title',
        'active_callback' => function () {
            if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design1') {
                return true;
            }
            return false;
        },
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner1_desc',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'magazinecraft_banner1_desc',
    array(
        'type'            => 'textarea',
        'label'           => esc_html__('Banner Description Text:', 'magazinecraft'),
        'section'         => 'magazinecraft_banner_section',
        'settings'        => 'magazinecraft_banner1_desc',
        'active_callback' => function () {
            if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design1') {
                return true;
            }
            return false;
        },
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner1_button_text',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'magazinecraft_banner1_button_text',
    array(
        'type'            => 'text',
        'label'           => esc_html__('Banner Button Text:', 'magazinecraft'),
        'section'         => 'magazinecraft_banner_section',
        'settings'        => 'magazinecraft_banner1_button_text',
        'active_callback' => function () {
            if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design1') {
                return true;
            }
            return false;
        },
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner1_button_link',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'magazinecraft_banner1_button_link',
    array(
        'type'            => 'text',
        'label'           => esc_html__('Banner Button Link:', 'magazinecraft'),
        'section'         => 'magazinecraft_banner_section',
        'settings'        => 'magazinecraft_banner1_button_link',
        'active_callback' => function () {
            if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design1') {
                return true;
            }
            return false;
        },
    )
);

$wp_customize->add_setting(
    'magazinecraft_banner1_bg_img',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'magazinecraft_banner1_bg_img', array(
    'label' => __('Banner Background Image', 'magazinecraft'),
    'section' => 'magazinecraft_banner_section',
    'setting' => 'magazinecraft_banner1_bg_img',
    'active_callback' => function () {
        if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design1') {
            return true;
        }
        return false;
    },
)));

$wp_customize->add_setting(
    'magazinecraft_banner2_category',
    array(
        'default'           => 0,
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint',
    )
);
$wp_customize->add_control(
    new Magazinecraft_Dropdown_Category_Control(
        $wp_customize,
        'magazinecraft_banner2_category',
        array(
            'section'         => 'magazinecraft_banner_section',
            'label'           => esc_html__('Banner Posts Category', 'magazinecraft'),
            'description'     => esc_html__('Select the category that the banner will show posts from. If no category is selected, the banner will show latest 5 posts.', 'magazinecraft'),
            'active_callback' => function () {
                if (get_theme_mod('magazinecraft_show_banner_section', true) && get_theme_mod('magazinecraft_banner_design', 'design1') === 'design2') {
                    return true;
                }
                return false;
            },
        )
    )
);
