<?php

/**
 * MagazineCraft Theme Customizer - Header options
 *
 * @package MagazineCraft
 */

// Add Header Options panel.
$wp_customize->add_panel(
    'magazinecraft_header_options',
    array(
        'capability'  => 'edit_theme_options',
        'description' => __('Change the Header Settings', 'magazinecraft'),
        'priority'    => 501,
        'title'       => __('Header Options', 'magazinecraft'),
    )
);

// Add main header design section.
$wp_customize->add_section(
    'magazinecraft_main_header_section',
    array(
        'title' => __('Main Header Area Options', 'magazinecraft'),
        'panel' => 'magazinecraft_header_options',
    )
);

$wp_customize->add_setting(
    'magazinecraft_main_header_design',
    array(
        'default'           => 'design1',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_radio',
    )
);
$wp_customize->add_control(
    'magazinecraft_main_header_design',
    array(
        'type'     => 'radio',
        'label'    => esc_html__('Main Header Design:', 'magazinecraft'),
        'section'  => 'magazinecraft_main_header_section',
        'settings' => 'magazinecraft_main_header_design',
        'choices'  => array(
            'design1' => esc_html__('Type 1', 'magazinecraft'),
            'design2' => esc_html__('Type 2', 'magazinecraft'),
        ),
    )
);

// Add top header bar settings section.
$wp_customize->add_section(
    'magazinecraft_top_bar_section',
    array(
        'title' => __('Header Top Bar', 'magazinecraft'),
        'panel' => 'magazinecraft_header_options',
    )
);

$wp_customize->add_setting(
    'magazinecraft_show_top_bar',
    array(
        'priority'          => 1,
        'default'           => true,
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'magazinecraft_show_top_bar',
    array(
        'type'     => 'checkbox',
        'label'    => __('Check to show the top bar in header', 'magazinecraft'),
        'section'  => 'magazinecraft_top_bar_section',
        'settings' => 'magazinecraft_show_top_bar',
    )
);

$wp_customize->add_setting(
    'magazinecraft_top_bar_theme',
    array(
        'default'           => 'dark',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_radio',
    )
);
$wp_customize->add_control(
    'magazinecraft_top_bar_theme',
    array(
        'type'            => 'radio',
        'label'           => esc_html__('Theme for Header Top Bar:', 'magazinecraft'),
        'section'         => 'magazinecraft_top_bar_section',
        'settings'        => 'magazinecraft_top_bar_theme',
        'active_callback' => 'magazinecraft_is_top_bar_active',
        'choices'         => array(
            'dark'  => esc_html__('Dark', 'magazinecraft'),
            'light' => esc_html__('Light', 'magazinecraft'),
        ),
    )
);


// Add section for Show Date.
$wp_customize->add_section(
    'magazinecraft_show_date_section',
    array(
        'title'           => esc_html__('Show Date', 'magazinecraft'),
        'panel'           => 'magazinecraft_header_options',
        'active_callback' => 'magazinecraft_is_top_bar_active',
    )
);

$wp_customize->add_setting(
    'magazinecraft_show_date_in_header',
    array(
        'priority'          => 1,
        'default'           => true,
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'magazinecraft_show_date_in_header',
    array(
        'type'     => 'checkbox',
        'label'    => __('Check to show the date top header bar', 'magazinecraft'),
        'section'  => 'magazinecraft_show_date_section',
        'settings' => 'magazinecraft_show_date_in_header',
    )
);

$wp_customize->add_setting(
    'magazinecraft_top_date_type',
    array(
        'default'           => 'theme_date_setting',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_radio',
    )
);
$wp_customize->add_control(
    'magazinecraft_top_date_type',
    array(
        'type'            => 'radio',
        'label'           => esc_html__('Format for Date in the Header:', 'magazinecraft'),
        'section'         => 'magazinecraft_show_date_section',
        'settings'        => 'magazinecraft_top_date_type',
        'active_callback' => 'magazinecraft_is_top_bar_active',
        'choices'         => array(
            'theme_date_setting'     => esc_html__('Theme Date Settings', 'magazinecraft'),
            'wordpress_date_setting' => esc_html__('WordPress Date Settings', 'magazinecraft'),
        ),
    )
);


// Add section for Social Media.
$wp_customize->add_section(
    'magazinecraft_social_media_section',
    array(
        'title'           => esc_html__('Social Media Links', 'magazinecraft'),
        'panel'           => 'magazinecraft_header_options',
        'active_callback' => 'magazinecraft_is_top_bar_active',
    )
);

$wp_customize->add_setting(
    'magazinecraft_show_social_in_top_bar',
    array(
        'priority'          => 1,
        'default'           => true,
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'magazinecraft_show_social_in_top_bar',
    array(
        'type'     => 'checkbox',
        'label'    => esc_html__('Check to show social media links in header top bar', 'magazinecraft'),
        'section'  => 'magazinecraft_social_media_section',
        'settings' => 'magazinecraft_show_social_in_top_bar',
    )
);

$magazinecraft_social_links = array(
    'magazinecraft_social_instagram'  => array(
        'id'      => 'magazinecraft_social_instagram',
        'title'   => esc_html__('Instagram Link', 'magazinecraft'),
        'default' => '',
    ),
    'magazinecraft_social_facebook'   => array(
        'id'      => 'magazinecraft_social_facebook',
        'title'   => esc_html__('Facebook Link', 'magazinecraft'),
        'default' => '',
    ),
    'magazinecraft_social_twitter'    => array(
        'id'      => 'magazinecraft_social_twitter',
        'title'   => esc_html__('Twitter Link', 'magazinecraft'),
        'default' => '',
    ),
    'magazinecraft_social_linkedin'   => array(
        'id'      => 'magazinecraft_social_linkedin',
        'title'   => esc_html__('LinkedIn Link', 'magazinecraft'),
        'default' => '',
    ),
    'magazinecraft_social_youtube'    => array(
        'id'      => 'magazinecraft_social_youtube',
        'title'   => esc_html__('YouTube Link', 'magazinecraft'),
        'default' => '',
    ),
    'magazinecraft_social_pinterest'  => array(
        'id'      => 'magazinecraft_social_pinterest',
        'title'   => esc_html__('Pinterest Link', 'magazinecraft'),
        'default' => '',
    ),
);

foreach ($magazinecraft_social_links as $magazinecraft_social_link) {
    $wp_customize->add_setting(
        $magazinecraft_social_link['id'],
        array(
            'default'           => $magazinecraft_social_link['default'],
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control(
        $magazinecraft_social_link['id'],
        array(
            'label'           => $magazinecraft_social_link['title'],
            'section'         => 'magazinecraft_social_media_section',
            'settings'        => $magazinecraft_social_link['id'],
            'active_callback' => 'magazinecraft_is_social_section_active',
        )
    );
}

$wp_customize->add_setting(
    'magazinecraft_display_header_media_on',
    array(
        'default'           => 'home',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'magazinecraft_sanitize_radio',
    )
);
$wp_customize->add_control(
    'magazinecraft_display_header_media_on',
    array(
        'type'     => 'radio',
        'label'    => esc_html__('Display Header Media On:', 'magazinecraft'),
        'section'  => 'header_image',
        'settings' => 'magazinecraft_display_header_media_on',
        'choices'  => array(
            'home' => esc_html__('Home Page Only', 'magazinecraft'),
            'all'  => esc_html__('All Pages', 'magazinecraft'),
        ),
    )
);
